@@ -66,6 +66,8 @@ class DefaultAlgorithm(AutoMLAlgorithm):
             AutoMLSearch will not use Elastic Net or XGBoost when there are more than 75 multiclass targets and will not use CatBoost when there are more than 150 multiclass targets. Defaults to False.
         features (list)[FeatureBase]: List of features to run DFS on in AutoML pipelines. Defaults to None. Features will only be computed if the columns used by the feature exist in the input and if the feature has not been computed yet.
         verbose (boolean): Whether or not to display logging information regarding pipeline building. Defaults to False.
+        exclude_featurizers (list[str]): A list of featurizer components to exclude from the pipelines built by DefaultAlgorithm.
+            Valid options are "DatetimeFeaturizer", "EmailFeaturizer", "URLFeaturizer", "NaturalLanguageFeaturizer", "TimeSeriesFeaturizer"
     """
 
     def __init__(
@@ -86,6 +88,7 @@ class DefaultAlgorithm(AutoMLAlgorithm):
         allow_long_running_models=False,
         features=None,
         verbose=False,
+        exclude_featurizers=None,
     ):
         super().__init__(
             allowed_pipelines=[],
@@ -114,6 +117,7 @@ class DefaultAlgorithm(AutoMLAlgorithm):
         self._X_without_cat_cols = None
         self.features = features
         self.ensembling = ensembling
+        self.exclude_featurizers = exclude_featurizers or []
 
         # TODO remove on resolution of 3186
         if is_time_series(self.problem_type) and self.ensembling:
@@ -138,6 +142,29 @@ class DefaultAlgorithm(AutoMLAlgorithm):
         """Returns the number of max batches AutoMLSearch should run by default."""
         return 4 if self.ensembling else 3
 
+    def num_pipelines_per_batch(self, batch_number):
+        """Return the number of pipelines in the nth batch.
+
+        Args:
+            batch_number (int): which batch to calculate the number of pipelines for.
+
+        Returns:
+            int: number of pipelines in the given batch.
+        """
+        if batch_number == 0 or batch_number == 1:
+            return len(self._naive_estimators())
+        elif batch_number == 2:
+            return len(self._non_naive_estimators())
+        if self.ensembling:
+            if batch_number % 2 != 0:
+                return 1
+            elif batch_number == 4:
+                return self.num_long_explore_pipelines * self.top_n
+        else:
+            if batch_number == 3:
+                return self.num_long_explore_pipelines * self.top_n
+        return self.num_long_pipelines_per_batch * self.top_n
+
     def _naive_estimators(self):
         if is_regression(self.problem_type):
             naive_estimators = [
@@ -154,6 +181,11 @@ class DefaultAlgorithm(AutoMLAlgorithm):
         ]
         return estimators
 
+    def _non_naive_estimators(self):
+        return list(
+            set(get_estimators(self.problem_type)) - set(self._naive_estimators()),
+        )
+
     def _init_pipelines_with_starter_params(self, pipelines):
         next_batch = []
         for pipeline in pipelines:
@@ -197,6 +229,7 @@ class DefaultAlgorithm(AutoMLAlgorithm):
                     None,
                 ),
                 features=self.features,
+                exclude_featurizers=self.exclude_featurizers,
             )
             for estimator in estimators
         ]
@@ -263,11 +296,7 @@ class DefaultAlgorithm(AutoMLAlgorithm):
         self._separate_hyperparameters_from_parameters()
 
     def _create_fast_final(self):
-        estimators = [
-            estimator
-            for estimator in get_estimators(self.problem_type)
-            if estimator not in self._naive_estimators()
-        ]
+        estimators = self._non_naive_estimators()
         estimators = self._filter_estimators(
             estimators,
             self.problem_type,
@@ -339,6 +368,7 @@ class DefaultAlgorithm(AutoMLAlgorithm):
                         None,
                     ),
                     features=self.features,
+                    exclude_featurizers=self.exclude_featurizers,
                 )
                 for estimator in estimators
             ]
@@ -421,14 +451,20 @@ class DefaultAlgorithm(AutoMLAlgorithm):
                 self._selected_cols,
                 self._selected_cat_cols,
             )
-        if list(self.X.ww.select("URL", return_schema=True).columns):
+        if (
+            list(self.X.ww.select("URL", return_schema=True).columns)
+            and "URLFeaturizer" not in self.exclude_featurizers
+        ):
             self._get_feature_provenance_and_remove_engineered_features(
                 pipeline,
                 URLFeaturizer.name,
                 self._selected_cat_cols,
                 self._selected_cat_cols,
             )
-        if list(self.X.ww.select("EmailAddress", return_schema=True).columns):
+        if (
+            list(self.X.ww.select("EmailAddress", return_schema=True).columns)
+            and "EmailFeaturizer" not in self.exclude_featurizers
+        ):
             self._get_feature_provenance_and_remove_engineered_features(
                 pipeline,
                 EmailFeaturizer.name,
@@ -527,6 +563,7 @@ class DefaultAlgorithm(AutoMLAlgorithm):
                 parameters=categorical_pipeline_parameters,
                 extra_components_before=[SelectColumns],
                 use_estimator=False,
+                exclude_featurizers=self.exclude_featurizers,
             )
 
             numeric_pipeline = make_pipeline(
@@ -539,6 +576,7 @@ class DefaultAlgorithm(AutoMLAlgorithm):
                 extra_components_before=[SelectByType],
                 extra_components_after=[SelectColumns],
                 use_estimator=False,
+                exclude_featurizers=self.exclude_featurizers,
             )
             prior_components = (
                 {"DFS Transformer": ["DFS Transformer", "X", "y"]}
@@ -572,6 +610,7 @@ class DefaultAlgorithm(AutoMLAlgorithm):
                 parameters=categorical_pipeline_parameters,
                 extra_components_before=[SelectColumns],
                 features=self.features,
+                exclude_featurizers=self.exclude_featurizers,
             )
             return categorical_pipeline
         else:
@@ -587,5 +626,6 @@ class DefaultAlgorithm(AutoMLAlgorithm):
                 parameters=numeric_pipeline_parameters,
                 extra_components_after=[SelectColumns],
                 features=self.features,
+                exclude_featurizers=self.exclude_featurizers,
             )
             return numeric_pipeline
