@@ -45,19 +45,19 @@ def log_error_callback(exception, traceback, automl, **kwargs):
     trace = "\n".join(traceback) if traceback else ""
     if isinstance(exception, PipelineScoreError):
         logger.warning(
-            f"\t\t\t{pipeline.name} fold {fold_num}: Encountered an error scoring the following objectives: {', '.join(exception.exceptions)}."
+            f"\t\t\t{pipeline.name} fold {fold_num}: Encountered an error scoring the following objectives: {', '.join(exception.exceptions)}.",
         )
         logger.warning(
-            f"\t\t\t{pipeline.name} fold {fold_num}: The scores for these objectives will be replaced with nan."
+            f"\t\t\t{pipeline.name} fold {fold_num}: The scores for these objectives will be replaced with nan.",
         )
         trace += f"\n{exception.message}"
     else:
         logger.warning(f"\t\t\t{pipeline.name} fold {fold_num}: Encountered an error.")
         logger.warning(
-            f"\t\t\t{pipeline.name} fold {fold_num}: All scores will be replaced with nan."
+            f"\t\t\t{pipeline.name} fold {fold_num}: All scores will be replaced with nan.",
         )
     logger.error(
-        f"\t\t\tFold {fold_num}: Exception during automl search: {str(exception)}"
+        f"\t\t\tFold {fold_num}: Exception during automl search: {str(exception)}",
     )
     logger.error(f"\t\t\tFold {fold_num}: Parameters:\n\t{pipeline.parameters}")
     logger.error(f"\t\t\tFold {fold_num}: Traceback:\n{trace}")
