@@ -43,6 +43,7 @@ class IDColumnsDataCheck(DataCheck):
             Columns that end in "_id" and are completely unique are likely to be ID columns.
 
             >>> df = pd.DataFrame({
+            ...     "profits": [25, 15, 15, 31, 19],
             ...     "customer_id": [123, 124, 125, 126, 127],
             ...     "Sales": [10, 42, 31, 51, 61]
             ... })
@@ -92,6 +93,7 @@ class IDColumnsDataCheck(DataCheck):
             by default and its name doesn't indicate that it's an ID.
 
             >>> df = pd.DataFrame({
+            ...    "humidity": ["high", "very high", "low", "low", "high"],
             ...    "Country_Rank": [1, 2, 3, 4, 5],
             ...    "Sales": ["very high", "high", "high", "medium", "very low"]
             ... })
@@ -99,7 +101,6 @@ class IDColumnsDataCheck(DataCheck):
             >>> id_col_check = IDColumnsDataCheck()
             >>> assert id_col_check.validate(df) == []
 
-
             However lowering the threshold will cause this column to be identified as an ID.
 
             >>> id_col_check = IDColumnsDataCheck()
@@ -121,6 +122,49 @@ class IDColumnsDataCheck(DataCheck):
             ...         ]
             ...     }
             ... ]
+
+            If the first column of the dataframe has all unique values and is named either 'ID' or a name that ends with '_id', it is probably the primary key.
+            The other ID columns should be dropped.
+
+            >>> df = pd.DataFrame({
+            ...     "sales_id": [0, 1, 2, 3, 4],
+            ...     "customer_id": [123, 124, 125, 126, 127],
+            ...     "Sales": [10, 42, 31, 51, 61]
+            ... })
+            ...
+            >>> id_col_check = IDColumnsDataCheck()
+            >>> assert id_col_check.validate(df) == [
+            ...     {
+            ...         "message": "The first column 'sales_id' is likely to be the primary key",
+            ...         "data_check_name": "IDColumnsDataCheck",
+            ...         "level": "warning",
+            ...         "code": "HAS_ID_FIRST_COLUMN",
+            ...         "details": {"columns": "sales_id", "rows": None},
+            ...         "action_options": [
+            ...             {
+            ...                 "code": "SET_FIRST_COL_ID",
+            ...                 "data_check_name": "IDColumnsDataCheck",
+            ...                 "parameters": {},
+            ...                 "metadata": {"columns": "sales_id", "rows": None}
+            ...             }
+            ...         ]
+            ...    },
+            ...    {
+            ...        "message": "Columns 'customer_id' are 100.0% or more likely to be an ID column",
+            ...         "data_check_name": "IDColumnsDataCheck",
+            ...         "level": "warning",
+            ...         "code": "HAS_ID_COLUMN",
+            ...         "details": {"columns": ["customer_id"], "rows": None},
+            ...         "action_options": [
+            ...             {
+            ...                 "code": "DROP_COL",
+            ...                 "data_check_name": "IDColumnsDataCheck",
+            ...                 "parameters": {},
+            ...                 "metadata": {"columns": ["customer_id"], "rows": None}
+            ...             }
+            ...         ]
+            ...    }
+            ... ]
         """
         messages = []
         X = infer_feature_types(X)
@@ -157,30 +201,54 @@ class IDColumnsDataCheck(DataCheck):
         id_cols_above_threshold = {
             key: value for key, value in id_cols.items() if value >= self.id_threshold
         }
+
         if id_cols_above_threshold:
-            warning_msg = "Columns {} are {}% or more likely to be an ID column"
-            messages.append(
-                DataCheckWarning(
-                    message=warning_msg.format(
-                        (", ").join(
-                            [
-                                "'{}'".format(str(col))
-                                for col in id_cols_above_threshold
-                            ],
-                        ),
-                        self.id_threshold * 100,
+            if (
+                col_names[0] in id_cols_above_threshold
+                and id_cols_above_threshold[col_names[0]] == 1.0
+            ):
+                del id_cols_above_threshold[col_names[0]]
+                warning_msg = "The first column '{}' is likely to be the primary key"
+                warning_msg = warning_msg.format(
+                    col_names[0],
+                )
+                messages.append(
+                    DataCheckWarning(
+                        message=warning_msg,
+                        data_check_name=self.name,
+                        message_code=DataCheckMessageCode.HAS_ID_FIRST_COLUMN,
+                        details={"columns": col_names[0]},
+                        action_options=[
+                            DataCheckActionOption(
+                                DataCheckActionCode.SET_FIRST_COL_ID,
+                                data_check_name=self.name,
+                                metadata={"columns": col_names[0]},
+                            ),
+                        ],
+                    ).to_dict(),
+                )
+            if id_cols_above_threshold:
+                warning_msg = "Columns {} are {}% or more likely to be an ID column"
+                warning_msg = warning_msg.format(
+                    (", ").join(
+                        ["'{}'".format(str(col)) for col in id_cols_above_threshold],
                     ),
-                    data_check_name=self.name,
-                    message_code=DataCheckMessageCode.HAS_ID_COLUMN,
-                    details={"columns": list(id_cols_above_threshold)},
-                    action_options=[
-                        DataCheckActionOption(
-                            DataCheckActionCode.DROP_COL,
-                            data_check_name=self.name,
-                            metadata={"columns": list(id_cols_above_threshold)},
-                        ),
-                    ],
-                ).to_dict(),
-            )
+                    self.id_threshold * 100,
+                )
+                messages.append(
+                    DataCheckWarning(
+                        message=warning_msg,
+                        data_check_name=self.name,
+                        message_code=DataCheckMessageCode.HAS_ID_COLUMN,
+                        details={"columns": list(id_cols_above_threshold)},
+                        action_options=[
+                            DataCheckActionOption(
+                                DataCheckActionCode.DROP_COL,
+                                data_check_name=self.name,
+                                metadata={"columns": list(id_cols_above_threshold)},
+                            ),
+                        ],
+                    ).to_dict(),
+                )
 
         return messages
