@@ -6,10 +6,7 @@ from evalml.data_checks import (
     DataCheckMessageCode,
     DataCheckWarning,
 )
-from evalml.utils.woodwork_utils import (
-    infer_feature_types,
-    numeric_and_boolean_ww,
-)
+from evalml.utils.woodwork_utils import infer_feature_types, numeric_and_boolean_ww
 
 
 class TargetLeakageDataCheck(DataCheck):
@@ -27,7 +24,7 @@ class TargetLeakageDataCheck(DataCheck):
     def __init__(self, pct_corr_threshold=0.95, method="mutual"):
         if pct_corr_threshold < 0 or pct_corr_threshold > 1:
             raise ValueError(
-                "pct_corr_threshold must be a float between 0 and 1, inclusive."
+                "pct_corr_threshold must be a float between 0 and 1, inclusive.",
             )
         if method not in ["mutual", "pearson"]:
             raise ValueError(f"Method '{method}' not in ['mutual', 'pearson']")
@@ -165,8 +162,8 @@ class TargetLeakageDataCheck(DataCheck):
                             DataCheckActionCode.DROP_COL,
                             data_check_name=self.name,
                             metadata={"columns": highly_corr_cols},
-                        )
+                        ),
                     ],
-                ).to_dict()
+                ).to_dict(),
             )
         return messages
