@@ -144,7 +144,7 @@ class ComponentGraph:
             if (
                 len(
                     list(
-                        filter(check_all_inputs_have_correct_syntax, component_inputs)
+                        filter(check_all_inputs_have_correct_syntax, component_inputs),
                     ),
                 )
                 != 0
@@ -245,6 +245,26 @@ class ComponentGraph:
         self._feature_provenance = self._get_feature_provenance(X.columns)
         return self
 
+    def fit_transform(self, X, y):
+        """Fit and transform all components in the component graph, if all components are Transformers.
+
+        Args:
+            X (pd.DataFrame): Input features of shape [n_samples, n_features].
+            y (pd.Series): The target data of length [n_samples].
+
+        Returns:
+            pd.DataFrame: Transformed output.
+
+        Raises:
+            ValueError: If final component is an Estimator.
+        """
+        final_component_instance = self.get_last_component()
+        if isinstance(final_component_instance, Estimator):
+            raise ValueError(
+                "Cannot call fit_transform() on a component graph because the final component is an Estimator. Use fit_and_transform_all_but_final instead.",
+            )
+        return self.fit(X, y).transform(X, y)
+
     def fit_and_transform_all_but_final(self, X, y):
         """Fit and transform all components save the final one, usually an estimator.
 
