@@ -5,10 +5,7 @@ import featuretools as ft
 from featuretools.primitives import NumCharacters, NumWords
 from nlp_primitives import DiversityScore, MeanCharactersPerWord, PolarityScore
 
-from evalml.pipelines.components.transformers.preprocessing import (
-    LSA,
-    TextTransformer,
-)
+from evalml.pipelines.components.transformers.preprocessing import LSA, TextTransformer
 from evalml.utils import infer_feature_types
 
 
@@ -134,7 +131,8 @@ class NaturalLanguageFeaturizer(TextTransformer):
         nan_mask = X[self._text_columns].isna()
         any_nans = nan_mask.any().any()
         X_nlp_primitives = ft.calculate_feature_matrix(
-            features=self._features, entityset=es
+            features=self._features,
+            entityset=es,
         )
         if X_nlp_primitives.isnull().any().any():
             X_nlp_primitives.fillna(0, inplace=True)
@@ -155,7 +153,7 @@ class NaturalLanguageFeaturizer(TextTransformer):
                 X_lsa.loc[nan_mask[column], derived_features] = None
         X_lsa.ww.init(logical_types={col: "Double" for col in X_lsa.columns})
         X_nlp_primitives.ww.init(
-            logical_types={col: "Double" for col in X_nlp_primitives.columns}
+            logical_types={col: "Double" for col in X_nlp_primitives.columns},
         )
         X_ww = X_ww.ww.drop(self._text_columns)
         for col in X_nlp_primitives:
