@@ -29,7 +29,7 @@ class PolynomialDetrender(Transformer):
                 degree = int(degree)
             else:
                 raise TypeError(
-                    f"Parameter Degree must be an integer!: Received {type(degree).__name__}"
+                    f"Parameter Degree must be an integer!: Received {type(degree).__name__}",
                 )
 
         params = {"degree": degree}
@@ -38,13 +38,16 @@ class PolynomialDetrender(Transformer):
 
         trend = import_or_raise("sktime.forecasting.trend", error_msg=error_msg)
         detrend = import_or_raise(
-            "sktime.transformations.series.detrend", error_msg=error_msg
+            "sktime.transformations.series.detrend",
+            error_msg=error_msg,
         )
 
         detrender = detrend.Detrender(trend.PolynomialTrendForecaster(degree=degree))
 
         super().__init__(
-            parameters=params, component_obj=detrender, random_seed=random_seed
+            parameters=params,
+            component_obj=detrender,
+            random_seed=random_seed,
         )
 
     def fit(self, X, y=None):
@@ -81,7 +84,8 @@ class PolynomialDetrender(Transformer):
             return X, y
         y_ww = infer_feature_types(y)
         y_t = self._component_obj.transform(y_ww)
-        y_t = infer_feature_types(pd.Series(y_t, index=y_ww.index))
+        y_t = pd.Series(y_t, index=y_ww.index)
+        y_t.ww.init(logical_type="double")
         return X, y_t
 
     def fit_transform(self, X, y=None):
