@@ -73,9 +73,12 @@ class BaseSampler(Transformer):
         Returns:
             pd.DataFrame, pd.Series: Transformed features and target.
         """
-        X_pd, y_pd = self._prepare_data(X, y)
-        X_new, y_new = self._component_obj.fit_resample(X_pd, y_pd)
-        return infer_feature_types(X_new), infer_feature_types(y_new)
+        X, y = self._prepare_data(X, y)
+        X_new, y_new = self._component_obj.fit_resample(X, y)
+
+        X_new.ww.init(schema=X.ww.schema)
+        y_new.ww.init(schema=y.ww.schema)
+        return X_new, y_new
 
     def _convert_dictionary(self, sampling_dict, y):
         """Converts the provided sampling dictionary from a dictionary of ratios to a dictionary of number of samples.
@@ -94,7 +97,7 @@ class BaseSampler(Transformer):
         y_unique = y.unique()
         if len(sampling_dict) != len(y_unique):
             raise ValueError(
-                "Sampling dictionary contains a different number of targets than are provided in the data."
+                "Sampling dictionary contains a different number of targets than are provided in the data.",
             )
 
         if len(set(sampling_dict.keys()).intersection(set(y_unique))) != len(y_unique):
@@ -127,7 +130,8 @@ class BaseSampler(Transformer):
         param_copy = copy.copy(self.parameters)
         if self.parameters["sampling_ratio_dict"]:
             new_dic = self._convert_dictionary(
-                self.parameters["sampling_ratio_dict"], y
+                self.parameters["sampling_ratio_dict"],
+                y,
             )
             param_copy["sampling_ratio_dict"] = new_dic
         return param_copy
