@@ -27,7 +27,7 @@ class PipelineBaseMeta(BaseMeta):
             klass = type(self).__name__
             if not self._is_fitted:
                 raise PipelineNotYetFittedError(
-                    f"This {klass} is not fitted yet. You must fit {klass} before calling {method.__name__}."
+                    f"This {klass} is not fitted yet. You must fit {klass} before calling {method.__name__}.",
                 )
 
             return method(self, *args, **kwargs)
