@@ -10,15 +10,20 @@ from evalml.automl.automl_algorithm import DefaultAlgorithm
 from evalml.model_family import ModelFamily
 from evalml.pipelines.components import (
     ARIMARegressor,
+    DateTimeFeaturizer,
     ElasticNetClassifier,
     ElasticNetRegressor,
+    EmailFeaturizer,
     LogisticRegressionClassifier,
+    NaturalLanguageFeaturizer,
     ProphetRegressor,
     RandomForestClassifier,
     StackedEnsembleClassifier,
     StackedEnsembleRegressor,
+    TimeSeriesFeaturizer,
+    URLFeaturizer,
 )
-from evalml.problem_types import ProblemTypes
+from evalml.problem_types import ProblemTypes, is_time_series
 
 
 def test_default_algorithm_init(X_y_binary):
@@ -922,3 +927,113 @@ def test_default_algorithm_accepts_URL_email_features(
         assert pipeline.parameters["Categorical Pipeline - Select Columns Transformer"][
             "columns"
         ] == ["url", "email"]
+
+
+@pytest.mark.parametrize(
+    "automl_type",
+    [ProblemTypes.BINARY, ProblemTypes.MULTICLASS, ProblemTypes.REGRESSION],
+)
+@pytest.mark.parametrize(
+    "ensembling",
+    [True, False],
+)
+@patch("evalml.pipelines.components.FeatureSelector.get_names")
+def test_default_algorithm_num_pipelines_per_batch(
+    mock_get_names,
+    automl_type,
+    ensembling,
+    X_y_categorical_classification,
+    X_y_multi,
+    X_y_regression,
+):
+    mock_get_names.return_value = None
+    if automl_type == ProblemTypes.BINARY:
+        X, y = X_y_categorical_classification
+    elif automl_type == ProblemTypes.MULTICLASS:
+        X, y = X_y_multi
+    elif automl_type == ProblemTypes.REGRESSION:
+        X, y = X_y_regression
+    algo = DefaultAlgorithm(
+        X=X,
+        y=y,
+        problem_type=automl_type,
+        sampler_name=None,
+        ensembling=ensembling,
+        top_n=2,
+        num_long_explore_pipelines=10,
+        num_long_pipelines_per_batch=5,
+    )
+    for i in range(7):
+        batch = algo.next_batch()
+        add_result(algo, batch)
+        assert len(batch) == algo.num_pipelines_per_batch(i)
+
+
+@pytest.mark.parametrize("input_type", ["pd", "ww"])
+@pytest.mark.parametrize("problem_type", ProblemTypes.all_problem_types)
+def test_exclude_featurizers_default_algorithm(
+    problem_type,
+    input_type,
+    get_test_data_from_configuration,
+):
+    parameters = {}
+    if is_time_series(problem_type):
+        parameters = {
+            "time_index": "dates",
+            "gap": 1,
+            "max_delay": 1,
+            "forecast_horizon": 3,
+        }
+
+    X, y = get_test_data_from_configuration(
+        input_type,
+        problem_type,
+        column_names=["dates", "text", "email", "url"],
+    )
+
+    algo = DefaultAlgorithm(
+        X,
+        y,
+        problem_type,
+        sampler_name=None,
+        search_parameters={"pipeline": parameters},
+        exclude_featurizers=[
+            "DatetimeFeaturizer",
+            "EmailFeaturizer",
+            "URLFeaturizer",
+            "NaturalLanguageFeaturizer",
+            "TimeSeriesFeaturizer",
+        ],
+    )
+
+    pipelines = []
+    for _ in range(4):
+        pipelines.extend([pl for pl in algo.next_batch()])
+
+    # A check to make sure we actually retrieve constructed pipelines from the algo.
+    assert len(pipelines) > 0
+
+    assert not any(
+        [
+            DateTimeFeaturizer.name in pl.component_graph.compute_order
+            for pl in pipelines
+        ],
+    )
+    assert not any(
+        [EmailFeaturizer.name in pl.component_graph.compute_order for pl in pipelines],
+    )
+    assert not any(
+        [URLFeaturizer.name in pl.component_graph.compute_order for pl in pipelines],
+    )
+    assert not any(
+        [
+            NaturalLanguageFeaturizer.name in pl.component_graph.compute_order
+            for pl in pipelines
+        ],
+    )
+    assert not any(
+        [
+            TimeSeriesFeaturizer.name in pl.component_graph.compute_order
+            for pl in pipelines
+        ],
+    )
