@@ -13,11 +13,15 @@ def test_catboost_classifier_random_seed_bounds_seed(X_y_binary):
     X = pd.DataFrame(X, columns=col_names)
     y = pd.Series(y)
     clf = CatBoostClassifier(
-        n_estimators=1, max_depth=1, random_seed=SEED_BOUNDS.min_bound
+        n_estimators=1,
+        max_depth=1,
+        random_seed=SEED_BOUNDS.min_bound,
     )
     clf.fit(X, y)
     clf = CatBoostClassifier(
-        n_estimators=1, max_depth=1, random_seed=SEED_BOUNDS.max_bound
+        n_estimators=1,
+        max_depth=1,
+        random_seed=SEED_BOUNDS.max_bound,
     )
     fitted = clf.fit(X, y)
     assert isinstance(fitted, CatBoostClassifier)
