@@ -7,8 +7,6 @@ from sklearn.preprocessing import PolynomialFeatures
 
 from evalml.pipelines.components import PolynomialDetrender
 
-pytestmark = pytest.mark.skip_if_39
-
 
 def test_polynomial_detrender_init():
     delayed_features = PolynomialDetrender(degree=3)
@@ -55,7 +53,7 @@ def test_polynomial_detrender_fit_transform(degree, use_int_index, input_type, t
     # Get the expected answer
     lin_reg = LinearRegression(fit_intercept=True)
     features = PolynomialFeatures(degree=degree).fit_transform(
-        np.arange(X_input.shape[0]).reshape(-1, 1)
+        np.arange(X_input.shape[0]).reshape(-1, 1),
     )
     lin_reg.fit(features, y_input)
     detrended_values = y_input.values - lin_reg.predict(features)
