@@ -638,19 +638,19 @@ class MockCheck2(DataCheck):
             [MockCheck],
             {"mock_check": {"foo": 1}},
             DataCheckInitError,
-            r"Encountered the following error while initializing mock_check: __init__\(\) missing 1 required positional argument: 'bar'",
+            r"Encountered the following error while initializing mock_check: .*__init__\(\) missing 1 required positional argument: 'bar'",
         ),
         (
             [MockCheck],
             {"mock_check": {"Bar": 2}},
             DataCheckInitError,
-            r"Encountered the following error while initializing mock_check: __init__\(\) got an unexpected keyword argument 'Bar'",
+            r"Encountered the following error while initializing mock_check: .*__init__\(\) got an unexpected keyword argument 'Bar'",
         ),
         (
             [MockCheck],
             {"mock_check": {"fo": 3, "ba": 4}},
             DataCheckInitError,
-            r"Encountered the following error while initializing mock_check: __init__\(\) got an unexpected keyword argument 'fo'",
+            r"Encountered the following error while initializing mock_check: .*__init__\(\) got an unexpected keyword argument 'fo'",
         ),
         (
             [MockCheck],
@@ -731,7 +731,7 @@ def test_errors_warnings_in_invalid_target_data_check(objective, ts_data):
     data_check_error_type = DataCheckError(
         message=f"Target data type should be numeric for regression type problems.",
         data_check_name="InvalidTargetDataCheck",
-        message_code=DataCheckMessageCode.TARGET_UNSUPPORTED_TYPE,
+        message_code=DataCheckMessageCode.TARGET_UNSUPPORTED_TYPE_REGRESSION,
     ).to_dict()
     for check in default_data_check:
         if check.name == "InvalidTargetDataCheck":
