@@ -16,13 +16,13 @@ no_variance_data_check_name = NoVarianceDataCheck.name
 all_distinct_X = pd.DataFrame({"feature": [1, 2, 3, 4]})
 all_null_X = pd.DataFrame({"feature": [None] * 4, "feature_2": list(range(4))})
 two_distinct_with_nulls_X = pd.DataFrame(
-    {"feature": [1, 1, None, None], "feature_2": list(range(4))}
+    {"feature": [1, 1, None, None], "feature_2": list(range(4))},
 )
 two_distinct_with_nulls_X_ww = two_distinct_with_nulls_X.copy()
 two_distinct_with_nulls_X_ww.ww.init()
 two_distinct_with_nulls_X_ww_nullable_types = two_distinct_with_nulls_X.copy()
 two_distinct_with_nulls_X_ww_nullable_types.ww.init(
-    logical_types={"feature": "IntegerNullable"}
+    logical_types={"feature": "IntegerNullable"},
 )
 
 all_distinct_y = pd.Series([1, 2, 3, 4])
@@ -31,7 +31,8 @@ two_distinct_with_nulls_y = pd.Series(([1] * 2) + ([None] * 2))
 two_distinct_with_nulls_y_ww = two_distinct_with_nulls_y.copy()
 two_distinct_with_nulls_y_ww.ww.init()
 two_distinct_with_nulls_y_ww_nullable_types = ww.init_series(
-    two_distinct_with_nulls_y.copy(), logical_type="IntegerNullable"
+    two_distinct_with_nulls_y.copy(),
+    logical_type="IntegerNullable",
 )
 all_null_y_with_name = pd.Series([None] * 4)
 all_null_y_with_name.name = "Labels"
@@ -153,7 +154,7 @@ cases = [
                 data_check_name=no_variance_data_check_name,
                 message_code=DataCheckMessageCode.NO_VARIANCE_ZERO_UNIQUE,
                 details={"columns": ["Labels"]},
-            ).to_dict()
+            ).to_dict(),
         ],
     ),
     (
@@ -193,7 +194,10 @@ cases = [
 
 @pytest.mark.parametrize("X, y, count_nan_as_value, expected_validation_result", cases)
 def test_no_variance_data_check_warnings(
-    X, y, count_nan_as_value, expected_validation_result
+    X,
+    y,
+    count_nan_as_value,
+    expected_validation_result,
 ):
     check = NoVarianceDataCheck(count_nan_as_value)
     assert check.validate(X, y) == expected_validation_result
